"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeWhitespaceBytewise = exports.getUhashSignature = void 0;
// This module implements the "uhash" signature specification described in docs/signature_specification.md
const crypto = require("crypto");
const binary_1 = require("./utils/binary");
const hashAlgorithm = 'md5';
exports.getUhashSignature = (filePath, fileContents) => {
    const digest = getUhashDigest(fileContents, binary_1.isBinary(fileContents));
    const data = digest.slice(0, 24);
    return {
        path: filePath,
        hashes_ffm: [
            {
                data,
                format: 3,
            },
        ],
    };
};
const getUhashDigest = (fileContents, isBinary) => {
    if (hashAlgorithm !== 'md5') {
        // placeholder for non-md5 hashing algorithm, e.g. xxhash
        throw new Error(`hashAlgorithm ${hashAlgorithm} is not supported`);
    }
    const file = isBinary ? fileContents : exports.removeWhitespaceBytewise(fileContents);
    const hash = crypto.createHash(hashAlgorithm).update(file);
    return hash.digest('hex');
};
exports.removeWhitespaceBytewise = (fileBuffer) => {
    const BYTES_TO_REMOVE = new Uint8Array([0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x20]);
    let writeIndex = 0;
    for (let readIndex = 0; readIndex < fileBuffer.length; readIndex++) {
        if (!BYTES_TO_REMOVE.includes(fileBuffer[readIndex])) {
            fileBuffer[writeIndex] = fileBuffer[readIndex];
            writeIndex++;
        }
    }
    return fileBuffer.slice(0, writeIndex);
};
//# sourceMappingURL=uhash.js.map